@@ -1492,6 +1492,10 @@ class AlistPath(Mapping, PathLike[str]):
         )
         return type(self)(self.fs, dst_path, dst_password)
 
+    @cached_property
+    def name(self, /) -> str:
+        return basename(self.path)
+
     def open(
         self, 
         /, 
@@ -1705,7 +1709,7 @@ class AlistFileReader(HTTPFileReader):
 
     @cached_property
     def name(self, /) -> str:
-        return self.path["name"]
+        return self.path.name
 
     @property # type: ignore
     def url(self) -> str:
